@@ -66,7 +66,7 @@ protected:
     {
         QAbstractItemView::dragMoveEvent(event);
 
-        const QModelIndex index = indexAt(event->pos());
+        const QModelIndex index = indexAt(event->position().toPoint());
 
         // This code has been copied from Dolphin
         // (panels/folders/paneltreeview.cpp)
@@ -84,7 +84,7 @@ protected:
     void dropEvent(QDropEvent *event) override
     {
         const QList<QUrl> urlList = KUrlMimeData::urlsFromMimeData(event->mimeData());
-        const QModelIndex index = indexAt(event->pos());
+        const QModelIndex index = indexAt(event->position().toPoint());
         if (!index.isValid()) {
             qCWarning(GWENVIEW_APP_LOG) << "Invalid index!";
             return;
